@@ -1,6 +1,7 @@
 import click
 import re
 
+from packaging import version
 from configparser import ConfigParser
 from tempfile import mkstemp
 from shutil import move, copymode
@@ -115,18 +116,24 @@ def replace(file_path: str, subst: str, section: str) -> (bool, str):
     return file_is_unchanged, path_changed
 
 
-def can_run_bump_version(new_version: str, project_dir: str) -> bool:
+def can_run_bump_version(new_version: str, project_dir: str, downgrade: bool) -> bool:
     """
     Ensure that all requirements are met, so that the bump version command can be run successfully.
     This included the following requirements:
-    1.) The new version matches the format [0-9]+.[0-9]+.[0-9]+
+    1.) The new version matches the format (?<!\.)\d+(?:\.\d+){2}(?:-SNAPSHOT)?(?!\.) # noqa: W605
     2.) The new version is greater than the current one
     3.) The project is a QUBE project
 
     :param new_version: The new version
     :param project_dir: The directory of the project
+    :param downgrade: Flag that indicates whether the user wants to downgrade the project version or not
     :return: True if bump version can be run, false otherwise.
     """
+    # parse the current version from the cfg file
+    parser = ConfigParser()
+    parser.read(f'{project_dir}/qube.cfg')
+    current_version = parser.get('bumpversion', 'current_version')
+
     # ensure that the entered version number matches correct format
     if not re.match(r'(?<!\.)\d+(?:\.\d+){2}(?:-SNAPSHOT)?(?!\.)', new_version):
         click.echo(click.style('Invalid version specified!\nEnsure your version number has the form '
@@ -140,16 +147,22 @@ def can_run_bump_version(new_version: str, project_dir: str) -> bool:
         return False
 
     # ensure the new version is greater than the current one
-    else:
-        parser = ConfigParser()
-        parser.read(f'{project_dir}/qube.cfg')
-        current_version = [int(digit) for digit in parser.get('bumpversion', 'current_version').replace('-SNAPSHOT', '').split('.')]
-        new_version = [int(digit) for digit in new_version.replace('-SNAPSHOT', '').split('.')]
+    # equal versions wont be accepted for bump-version
+    elif new_version == current_version:
+        click.echo(click.style(f'The new version {new_version} cannot be equal to the current version {current_version}.', fg='red'))
+        return False
+
+    # ensure the new version is greater than the current one, if not the user wants to explicitly downgrade it
+    elif not downgrade:
+        current_version_r = current_version.replace('-SNAPSHOT', '')
+        new_version_r = new_version.replace('-SNAPSHOT', '')
         is_greater = False
 
-        if new_version[0] > current_version[0] or new_version[0] == current_version[0] and new_version[1] > current_version[1]:
+        # when the current version and the new version are equal, but one is a -SNAPSHOT version return true
+        if version.parse(current_version_r) == version.parse(new_version_r) and ('-SNAPSHOT' in current_version or '-SNAPSHOT' in new_version):
             is_greater = True
-        elif new_version[0] == current_version[0] and new_version[1] == current_version[1] and new_version[2] > current_version[2]:
+        # else check if the new version is greater than the current version
+        elif version.parse(current_version_r) < version.parse(new_version_r):
             is_greater = True
 
         # the new version is not greater than the current one
@@ -159,3 +172,4 @@ def can_run_bump_version(new_version: str, project_dir: str) -> bool:
                 f'\nNew version must be greater than the old one.', fg='red'))
 
         return is_greater
+    return True
