@@ -1,23 +1,21 @@
 import os
 import sys
+import click
 import shutil
 import tempfile
 import requests
 from distutils.dir_util import copy_tree
-from shutil import copy2
 from pathlib import Path
 from dataclasses import asdict
-
-import click
 from ruamel.yaml import YAML
 from cookiecutter.main import cookiecutter
 
-from qube.create.domains.QubeTemplateStruct import QubeTemplateStruct
 from qube.util.dir_util import delete_dir_tree
 from qube.create.github_support import create_push_github_repository, load_github_username
 from qube.lint.lint import lint_project
 from qube.util.docs_util import fix_short_title_underline
 from qube.list.list import load_available_templates
+from qube.create.domains.QubeTemplateStruct import QubeTemplateStruct
 
 
 class TemplateCreator:
@@ -30,18 +28,18 @@ class TemplateCreator:
     def __init__(self, creator_ctx: QubeTemplateStruct):
         self.WD = os.path.dirname(__file__)
         self.TEMPLATES_PATH = f'{self.WD}/templates'
-        self.COMMON_FILES_PATH = f'{self.WD}/templates/common_files'
-        self.AVAILABLE_TEMPLATES_PATH = f'{self.WD}/templates/available_templates.yml'
+        self.COMMON_FILES_PATH = f'{self.TEMPLATES_PATH}/common_files'
+        self.AVAILABLE_TEMPLATES_PATH = f'{self.TEMPLATES_PATH}/available_templates.yml'
         self.AVAILABLE_TEMPLATES = load_available_templates(self.AVAILABLE_TEMPLATES_PATH)
         self.CWD = os.getcwd()
         self.creator_ctx = creator_ctx
 
     def process_common_operations(self, skip_common_files=False, skip_fix_underline=False) -> None:
         """
-        Create all stuff that is common for QUBE's template creation process; in detail those things are:
+        Create all stuff that is common for qubes template creation process; in detail those things are:
         create and copy common files, fix docs style, lint the project and ask whether the user wants to create a github repo.
         """
-        # create the common files and copy them into the templates directory
+        # create the common files and copy them into the templates directory (skip if flag is set)
         if not skip_common_files:
             self.create_common_files()
 
@@ -50,7 +48,7 @@ class TemplateCreator:
         project_name = self.creator_ctx.project_slug
         project_path = f'{self.CWD}/{project_name}'
 
-        # Ensure that docs are looking good
+        # Ensure that docs are looking good (skip if flag is set)
         if not skip_fix_underline:
             fix_short_title_underline(f'{project_path}/docs/index.rst')
 
@@ -66,10 +64,7 @@ class TemplateCreator:
             # rename the currently created template to a temporary name, create Github repo, push, remove temporary template
             tmp_project_path = f'{project_path}_qube_tmp'
             os.rename(project_path, tmp_project_path)
-            create_push_github_repository(project_name,
-                                          self.creator_ctx.project_short_description,
-                                          tmp_project_path,
-                                          self.creator_ctx.github_username)
+            create_push_github_repository(project_name, self.creator_ctx.project_short_description, tmp_project_path, self.creator_ctx.github_username)
             shutil.rmtree(tmp_project_path, ignore_errors=True)
 
     def create_template_without_subdomain(self, domain_path: str) -> None:
@@ -80,10 +75,11 @@ class TemplateCreator:
         :param domain_path: Path to the template, which is still in cookiecutter format
         """
         # Target directory is already occupied -> overwrite?
-        occupied = os.path.isdir(f"{os.getcwd()}/{self.creator_ctx.project_slug}")
+        occupied = os.path.isdir(f'{os.getcwd()}/{self.creator_ctx.project_slug}')
         if occupied:
             self.directory_exists_warning()
 
+            # Confirm proceeding with overwriting existing directory
             if click.confirm('Do you really want to continue?'):
                 cookiecutter(f'{domain_path}/{self.creator_ctx.domain}_{self.creator_ctx.language.lower()}',
                              no_input=True,
@@ -106,10 +102,11 @@ class TemplateCreator:
         :param domain_path: Path to the template, which is still in cookiecutter format
         :param subdomain: Subdomain of the chosen template
         """
-        occupied = os.path.isdir(f"{os.getcwd()}/{self.creator_ctx.project_slug}")
+        occupied = os.path.isdir(f'{os.getcwd()}/{self.creator_ctx.project_slug}')
         if occupied:
             self.directory_exists_warning()
 
+            # Confirm proceeding with overwriting existing directory
             if click.confirm('Do you really want to continue?'):
                 cookiecutter(f'{domain_path}/{subdomain}_{self.creator_ctx.language.lower()}',
                              no_input=True,
@@ -134,10 +131,11 @@ class TemplateCreator:
         :param subdomain: Subdomain of the chosen template
         :param framework: Chosen framework
         """
-        occupied = os.path.isdir(f"{os.getcwd()}/{self.creator_ctx.project_slug}")
+        occupied = os.path.isdir(f'{os.getcwd()}/{self.creator_ctx.project_slug}')
         if occupied:
             self.directory_exists_warning()
 
+            # Confirm proceeding with overwriting existing directory
             if click.confirm('Do you really want to continue?'):
                 cookiecutter(f'{domain_path}/{subdomain}_{self.creator_ctx.language.lower()}/{framework}',
                              no_input=True,
@@ -158,7 +156,6 @@ class TemplateCreator:
         Prompts the user for general options that are required by all templates.
         Options are saved in the creator context manager object.
         """
-
         self.creator_ctx.full_name = click.prompt('Please enter your full name',
                                                   type=str,
                                                   default='Homer Simpson')
@@ -170,13 +167,17 @@ class TemplateCreator:
         # check if the project name is already taken on readthedocs.io
         while self.readthedocs_slug_already_exists(self.creator_ctx.project_name):
             click.echo(click.style(f'A project named {self.creator_ctx.project_name} already exists at readthedocs.io!', fg='red'))
-            if click.confirm(click.style('Do you want to choose another name for your project?\nOtherwise you are not able to host your docs at '
+            if click.confirm(click.style('Do you want to choose another name for your project?\nOtherwise you will not be able to host your docs at '
                                          'readthedocs.io!', fg='blue')):
                 self.creator_ctx.project_name = click.prompt('Please enter your project name', type=str, default='Exploding Springfield')
+            # break if the project should be named anyways
+            else:
+                break
+
         self.creator_ctx.project_slug = self.creator_ctx.project_name.replace(' ', '_')
         self.creator_ctx.project_short_description = click.prompt('Please enter a short description of your project.',
                                                                   type=str,
-                                                                  default=f'{self.creator_ctx.project_name}. Nuclear physics simulation software.')
+                                                                  default=f'{self.creator_ctx.project_name}. A best practice .')
         self.creator_ctx.github_username = load_github_username()
 
     def create_common_files(self) -> None:
@@ -184,12 +185,11 @@ class TemplateCreator:
         This function creates a temporary directory for common files of all templates and applies cookiecutter on them.
         They are subsequently moved into the directory of the created template.
         """
-
-        tmp_dir = tempfile.mkdtemp()
-        copy_tree(f'{self.COMMON_FILES_PATH}', tmp_dir)
+        dirpath = tempfile.mkdtemp()
+        copy_tree(f'{self.COMMON_FILES_PATH}', dirpath)
         cwd_project = Path.cwd()
-        os.chdir(tmp_dir)
-        cookiecutter(tmp_dir,
+        os.chdir(dirpath)
+        cookiecutter(dirpath,
                      extra_context={'full_name': self.creator_ctx.full_name,
                                     'email': self.creator_ctx.email,
                                     'language': self.creator_ctx.language,
@@ -199,62 +199,35 @@ class TemplateCreator:
                      no_input=True,
                      overwrite_if_exists=True)
 
-        common_files = os.listdir(f'{os.getcwd()}/common_files_util/')
-
-        for f in common_files:
-            path = Path(f'{os.getcwd()}/common_files_util/{f}')
-            poss_dir = Path(f"{cwd_project}/{self.creator_ctx.project_slug}/{f}")
-            is_dir = poss_dir.is_dir()
-
-            if is_dir:
-                if any(Path(poss_dir).iterdir()):
-                    self.copy_into_already_existing_directory(path, poss_dir)
-
-            else:
-                if is_dir:
-                    delete_dir_tree(poss_dir)
-                shutil.copy(path, f"{cwd_project}/{self.creator_ctx.project_slug}/{f}")
-                os.remove(path)
-
+        # recursively copy the common files directory content to the created project
+        copy_tree(f'{os.getcwd()}/common_files_util', f'{cwd_project}/{self.creator_ctx.project_slug}')
+        # delete the tmp cookiecuttered common files directory
         delete_dir_tree(Path(f'{Path.cwd()}/common_files_util'))
-        shutil.rmtree(tmp_dir)
+        shutil.rmtree(dirpath)
+        # change to recent cwd so lint etc can run properly
         os.chdir(str(cwd_project))
 
     def readthedocs_slug_already_exists(self, project_name: str) -> bool:
         """
-        Test if there´s already a project with the same name on readthedocs
+        Test whether there´s already a project with the same name on readthedocs
         :param project_name Name of the project the user wants to create
         """
-        request = requests.get(f'https://{project_name.replace(" ", "")}.readthedocs.io')
-        if request.status_code == 200:
-            return True
-        else:
+        try:
+            request = requests.get(f'https://{project_name.replace(" ", "")}.readthedocs.io')
+            if request.status_code == 200:
+                return True
+        # catch exceptions when server may be unavailable or the request timed out
+        except (requests.exceptions.ConnectionError, requests.exceptions.Timeout):
+            click.echo(click.style('Cannot check whether name already taken on readthedocs.io because its unreachable at the moment!', fg='red'))
             return False
 
-    def copy_into_already_existing_directory(self, common_path, dir: Path) -> None:
-        """
-        This function copies all files of an arbitrarily deep nested directory that is already on the main directory
-        and just adds them where they belong.
-
-        :param common_path: Path where the common files are located
-        :param dir: The projects directory where collisions occurred (co-existence)
-        """
-        for child in common_path.iterdir():
-            if child.is_dir():
-                p = Path(f'{dir}/{child.name}')
-                if p.exists():
-                    self.copy_into_already_existing_directory(child.resolve(), p)
-                else:
-                    shutil.copytree(str(child), str(p))
-            if not child.is_dir():
-                copy2(str(child), str(dir))
-
     def directory_exists_warning(self) -> None:
         """
         Prints warning that a directory already exists and any further action on the directory will overwrite its contents.
         """
+
         click.echo(click.style('WARNING: ', fg='red')
-                   + click.style(f"A directory named {self.creator_ctx.project_slug} already exists at", fg='red')
+                   + click.style(f'A directory named {self.creator_ctx.project_slug} already exists at', fg='red')
                    + click.style(f'{os.getcwd()}', fg='green'))
         click.echo()
         click.echo(click.style('Proceeding now will overwrite this directory and its content!', fg='red'))
@@ -276,7 +249,6 @@ class TemplateCreator:
     def creator_ctx_to_dict(self) -> dict:
         """
         Create a dict from the our Template Structure dataclass
-
         :return: The dict containing all key-value pairs with non empty values
         """
         return {key: val for key, val in asdict(self.creator_ctx).items() if val != ''}
@@ -284,8 +256,7 @@ class TemplateCreator:
     def load_version(self, handle: str) -> str:
         """
         Load the version of the template specified by the handler
-        TODO: Maybe recursive one for arbitrary length (tough I Dont think we will need it)
-
+        TODO: Maybe recursive one for arbitray length (tough I Dont think we will need it)
         :param handle: The template handle
         :return: The version number
         """
